@@ -1,15 +1,15 @@
 /* ====================================================================
- * Copyright (c) 2005-2015 Open Source Applications Foundation.
+ * Copyright (c) 2005-2018 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
  * to deal in the Software without restriction, including without limitation
  * the rights to use, copy, modify, merge, publish, distribute, sublicense,
  * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions: 
+ * Software is furnished to do so, subject to the following conditions:
  *
  * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software. 
+ * in all copies or substantial portions of the Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
  * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -182,7 +182,8 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/uspoof.h>
 #include <unicode/tmunit.h>
 #include <unicode/tmutamt.h>
-#include <unicode/stringpiece.h>
+#include <unicode/numsys.h>
+
 #endif
 
 #if U_ICU_VERSION_HEX >= 0x04040000
@@ -194,6 +195,10 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <typeinfo>
 #endif
 
+#if U_ICU_VERSION_HEX >= 0x04080000
+#include <unicode/alphaindex.h>
+#endif
+
 #if U_ICU_VERSION_HEX >= VERSION_HEX(50, 0, 0)
 #include <unicode/listformatter.h>
 #endif
@@ -213,6 +218,11 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/simpleformatter.h>
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(59, 0, 0)
+#include <unicode/casemap.h>
+#include <unicode/edits.h>
+#endif
+
 #if U_ICU_VERSION_HEX >= VERSION_HEX(60, 0, 0)
 #include <unicode/nounit.h>
 #include <unicode/numberformatter.h>
@@ -240,6 +250,7 @@ enum {
     UnicodeMatcher_ID,
     SearchIterator_ID,
     ListFormatter_ID,
+    CaseMap_ID,
 };
 
 #else
@@ -251,7 +262,7 @@ typedef const char *classid;
 
 U_NAMESPACE_USE
 
-/* lifted from ustrenum.h */
+/* lifted from common/ustrenum.h */
 
 U_NAMESPACE_BEGIN
 class U_COMMON_API UStringEnumeration : public StringEnumeration {
@@ -272,6 +283,18 @@ extern PyObject *PyExc_InvalidArgsError;
 
 void _init_common(PyObject *m);
 
+class Buffer {
+public:
+    explicit Buffer(int32_t len) :
+    size(len), buffer(u.getBuffer(len)) {}
+    ~Buffer() {
+        u.releaseBuffer(0);
+    }
+    UnicodeString u;
+    int32_t size;
+    UChar *buffer;
+};
+
 class ICUException {
 private:
     PyObject *code;
